@@ -34,20 +34,10 @@ from duplicity import log
 from duplicity import pexpect
 from duplicity.errors import *
 
-scp_command = "scp"
-sftp_command = "sftp"
-
-# default to batch mode using public-key encryption
-ssh_askpass = False
-
-# user added ssh options
-ssh_options = ""
-
 class SSHBackend(duplicity.backend.Backend):
     """This backend copies files using scp.  List not supported"""
     def __init__(self, parsed_url):
         """scpBackend initializer"""
-        global ssh_askpass
         duplicity.backend.Backend.__init__(self, parsed_url)
 
         # host string of form [user@]hostname
@@ -64,19 +54,19 @@ class SSHBackend(duplicity.backend.Backend):
         self.remote_prefix = self.remote_dir + '/'
         # maybe use different ssh port
         if parsed_url.port:
-            self.ssh_options = ssh_options + " -oPort=%s" % parsed_url.port
+            globals.ssh_options = globals.ssh_options + " -oPort=%s" % parsed_url.port
         else:
-            self.ssh_options = ssh_options
+            globals.ssh_options = globals.ssh_options
         # set network timeout.  CountMax is how many retries to do, not how many tries.
         # Use CountMax=1 just in case there's a tiny network blip.
-        self.ssh_options += " -oServerAliveInterval=%i -oServerAliveCountMax=1" % ((int)(globals.timeout / 2))
+        globals.ssh_options += " -oServerAliveInterval=%i -oServerAliveCountMax=1" % ((int)(globals.timeout / 2))
         # set up password
-        if ssh_askpass:
+        if globals.ssh_askpass:
             self.password = self.get_password()
         else:
             if parsed_url.password:
                 self.password = parsed_url.password
-                ssh_askpass = True
+                globals.ssh_askpass = True
             else:
                 self.password = ''
 
@@ -89,7 +79,7 @@ class SSHBackend(duplicity.backend.Backend):
             log.Info("Running '%s' (attempt #%d)" % (commandline, n))
             child = pexpect.spawn(commandline, timeout = None)
             cmdloc = 0
-            if ssh_askpass:
+            if globals.ssh_askpass:
                 state = "authorizing"
             else:
                 state = "copying"
@@ -198,7 +188,7 @@ class SSHBackend(duplicity.backend.Backend):
                     log.Warn("Host key authenticity could not be verified (missing known_hosts entry?)")
                     break
                 elif match == 6:
-                    log.Warn("Remote file or directory '%s' does not exist" % self.remote_dir)
+                    log.Warn("Remote file or directory does not exist in command='%s'" % (command,))
                     break
             child.close(force = True)
             if child.exitstatus == 0:
@@ -208,20 +198,24 @@ class SSHBackend(duplicity.backend.Backend):
         raise BackendException("Error running '%s'" % commandline)
 
     def put(self, source_path, remote_filename = None):
-        """Use scp to copy source_dir/filename to remote computer"""
+        """Use sftp to copy source_dir/filename to remote computer"""
         if not remote_filename:
             remote_filename = source_path.get_filename()
-        commandline = "%s %s %s %s:%s%s" % \
-            (scp_command, self.ssh_options, source_path.name, self.host_string,
-             self.remote_prefix, remote_filename)
-        self.run_scp_command(commandline)
+        commands = ["put %s %s%s" %
+                    (source_path.name, self.remote_prefix, remote_filename)]
+        commandline = ("%s %s %s" % (globals.sftp_command,
+                                     globals.ssh_options,
+                                     self.host_string))
+        self.run_sftp_command(commandline, commands)
 
     def get(self, remote_filename, local_path):
-        """Use scp to get a remote file"""
-        commandline = "%s %s %s:%s%s %s" % \
-            (scp_command, self.ssh_options, self.host_string, self.remote_prefix,
-             remote_filename, local_path.name)
-        self.run_scp_command(commandline)
+        """Use sftp to get a remote file"""
+        commands = ["get %s%s %s" %
+                    (self.remote_prefix, remote_filename, local_path.name)]
+        commandline = ("%s %s %s" % (globals.sftp_command,
+                                     globals.ssh_options,
+                                     self.host_string))
+        self.run_sftp_command(commandline, commands)
         local_path.setdata()
         if not local_path.exists():
             raise BackendException("File %s not found locally after get "
@@ -238,8 +232,8 @@ class SSHBackend(duplicity.backend.Backend):
         commands = ["mkdir %s" % (self.remote_dir,),
                     "cd %s" % (self.remote_dir,),
                     "ls -1"]
-        commandline = ("%s %s %s" % (sftp_command,
-                                     self.ssh_options,
+        commandline = ("%s %s %s" % (globals.sftp_command,
+                                     globals.ssh_options,
                                      self.host_string))
 
         l = self.run_sftp_command(commandline, commands).split('\n')[1:]
@@ -253,7 +247,7 @@ class SSHBackend(duplicity.backend.Backend):
         commands = ["cd %s" % (self.remote_dir,)]
         for fn in filename_list:
             commands.append("rm %s" % fn)
-        commandline = ("%s %s %s" % (sftp_command, self.ssh_options, self.host_string))
+        commandline = ("%s %s %s" % (globals.sftp_command, globals.ssh_options, self.host_string))
         self.run_sftp_command(commandline, commands)
 
 duplicity.backend.register_backend("ssh", SSHBackend)
